%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This program is used to plot the confusion pattern of normal hearing
% Hearing Impaired 06.
%   Author:      Feipeng Li at HSR, Beckman Institute, UIUC
%   Time-stamp:  2006-10-10
%   E-mail:      fli2@uiuc.edu
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function plot_CV06SWNV_CP(Table, snrs, cur_snr, Resp, Utter)

% the PI for SNR = -21dB is totally unreliable, get rid of it.
%Table = Table(:,2:end); 
%SNR = SNR(2:end);

Resp = strrep(Resp, 'xi', '');
Resp = strrep(Resp, 'xq', '');
Resp = strrep(Resp, 'xu', '');
Resp = strrep(Resp, 'xe', '');
Resp = strrep(Resp, 'xr', '');
Resp = strrep(Resp, 'xs', 'S');
Resp = strrep(Resp, 'xz', 'Z');
Resp = strrep(Resp, 'a', '');
Resp = strrep(Resp, 'o', '');
Resp = strrep(Resp, 'u', '');

% move the row for '?' to the end of the table
tf = strcmp(Resp, '?');
p = find(tf);
temp1 = Table(p,:);
temp2 = Table(p+1:end,:);
Table(p:end-1,:) = temp2;
Table(end,:) = temp1;
temp1 = Resp{p};
temp2 = {Resp{1:p-1}};
temp3 = {Resp{p+1:end}};
Resp = cat(2, temp2, temp3);
Resp{end+1} = temp1;

[nRow, nCol] = size(Table); nRow = round(nRow/8);

table_temp = zeros(nRow, nCol);
for i=1:nRow
    for j=1:8
        table_temp(i,:) = table_temp(i,:)+Table((i-1)*8+j,:);
        resp_temp{i} = Resp{(i-1)*8+j};
    end
end
table_temp(end+1,:) = Table(end,:);
resp_temp{end+1} = Resp{end};

Table = table_temp;
Resp = resp_temp;
[nRow, nCol] = size(Table);

markers_code = create_markers_code();

%scrsz = get(0,'ScreenSize');
%figure('Position',[1 1 scrsz(3)/1.2 scrsz(4)/1.2]);
%figure

p_chance = 1/9;
S = sum(Table(1:nRow, :))+ eps; % total num of presentation 
for j=1:nRow
    if (max(Table(j,:))>1)
        pi_row = Table(j,:)./S;
        idx = find(pi_row<p_chance);
        pi_row(idx) = p_chance;
        
        plot(snrs, log10(pi_row), markers_code{j}.shape, 'Color', markers_code{j}.color,...
            'MarkerFacecolor', markers_code{j}.facecolor, 'MarkerSize', 4 ,'LineWidth',1.5 ); hold on
        p = max(find(Table(j,:)==max(Table(j,:)))); 
        x = snrs(p);  y = Table(j,p)./S(p);
        if (y>p_chance)&&(y<1.1)
            text(double(x), log10(y), Resp(j), 'VerticalAlignment','baseline', 'Color', 'k', 'FontSize', 8, 'FontWeight','bold');
        end
    else
       %plot(snrs, cm1(j,:)./S, '--o', 'Color', color_codes(j-1,:)); hold on
    end
end

hold on
line([cur_snr cur_snr],[log10(0.01) log10(1.05)],'Color', 'r' ,'Linewidth', 2, 'Linestyle', '--');
hold off

utterance = fix_underscore(Utter);
grid on; xlim([snrs(1)-2,snrs(end)+2]); ylim([log10(p_chance), log10(1.05)]); 
title(['Confusion Patterns of ' utterance ], 'FontSize', 9);
set(gca,'XTick',snrs,'YTick',log10([0.1,0.2,0.4,0.6,0.8,1]), 'YTickLabel', [0.1,0.2,0.4,0.6,0.8,1], 'FontSize', 9);
xlabel('SNR(dB)', 'FontSize', 9); ylabel('P_{h|s}(SNR)', 'FontSize', 9); 
%legend(Resp,'Location','EastOutside');
